@@ -231,11 +231,21 @@ fit <- eBayes(fit)
 res <- decideTests(fit, p.value=0.01)
 summary(res)
 
+## ----setsizebysigma, height=700, width=500, fig.cap="Residual standard deviation of GSVA scores as function of gene set size."----
+gssizes <- geneSetSizes(leukemia_es)
+plot(sqrt(gssizes), sqrt(fit$sigma), xlab="Sqrt(gene sets sizes)",
+     ylab="Sqrt(standard deviation)", las=1, pch=".", cex=3)
+
+## -----------------------------------------------------------------------------
+fit <- eBayes(fit, trend=gssizes)
+res <- decideTests(fit, p.value=0.01)
+summary(res)
+
 ## ----leukemiavolcano, height=700, width=500, fig.cap="Volcano plot for the differential expression analysis at pathway level between two leukemia subtypes."----
 tt <- topTable(fit, coef=2, n=Inf)
 DEpwys <- rownames(tt)[tt$adj.P.Val <= 0.01]
 plot(tt$logFC, -log10(tt$P.Value), pch=".", cex=4, col=grey(0.75),
-     main="", xlab="GSVA enrichment score difference",
+     main="", xlab="GSVA enrichment score difference", las=1,
      ylab=expression(-log[10]~~Raw~P-value))
 abline(h=-log10(max(tt$P.Value[tt$adj.P.Val <= 0.01])),
        col=grey(0.5), lwd=1, lty=2)
